'use strict';

var getPrivateKey = function () {
    var _ref = _asyncToGenerator(regeneratorRuntime.mark(function _callee(privateKeyFile) {
        var privateKeyText;
        return regeneratorRuntime.wrap(function _callee$(_context) {
            while (1) {
                switch (_context.prev = _context.next) {
                    case 0:
                        _context.next = 2;
                        return _fsPromise2.default.readFile(privateKeyFile, 'utf-8');

                    case 2:
                        privateKeyText = _context.sent;
                        return _context.abrupt('return', openpgp.key.readArmored(privateKeyText).keys[0]);

                    case 4:
                    case 'end':
                        return _context.stop();
                }
            }
        }, _callee, this);
    }));

    return function getPrivateKey(_x) {
        return _ref.apply(this, arguments);
    };
}();

var decryptPrivateKey = function () {
    var _ref2 = _asyncToGenerator(regeneratorRuntime.mark(function _callee2(privateKey) {
        var ok, firstTry, passphrase;
        return regeneratorRuntime.wrap(function _callee2$(_context2) {
            while (1) {
                switch (_context2.prev = _context2.next) {
                    case 0:
                        ok = false;
                        firstTry = true;

                    case 2:
                        if (!firstTry) {
                            console.log('Wrong passphrase.');
                        }
                        _context2.next = 5;
                        return (0, _passwordPrompt2.default)('Private key passphrase: ', { method: 'hide' });

                    case 5:
                        passphrase = _context2.sent;

                        ok = privateKey.decrypt(passphrase);
                        firstTry = false;

                    case 8:
                        if (!ok) {
                            _context2.next = 2;
                            break;
                        }

                    case 9:
                    case 'end':
                        return _context2.stop();
                }
            }
        }, _callee2, this);
    }));

    return function decryptPrivateKey(_x2) {
        return _ref2.apply(this, arguments);
    };
}();

var getParams = function () {
    var _ref3 = _asyncToGenerator(regeneratorRuntime.mark(function _callee3() {
        var outputDirectory, errors, privateKey;
        return regeneratorRuntime.wrap(function _callee3$(_context3) {
            while (1) {
                switch (_context3.prev = _context3.next) {
                    case 0:
                        outputDirectory = '';

                        _commander2.default.description('Export your ProtonMail e-mails.').usage('[options] <existing_output_directory>').option('-c, --cookie <string>', 'specify the cookie header to send to the API (required)').option('-i, --session-id <string>', 'specify a valid session ID (required)').option('-p, --private-key-file <path>', 'specify the path to a text file containing the private key (required)').action(function (_outputDirectory) {
                            return outputDirectory = _outputDirectory;
                        }).parse(process.argv);

                        errors = [];

                        if (outputDirectory) {
                            _context3.next = 7;
                            break;
                        }

                        errors.push('Output directory is required.');
                        _context3.next = 11;
                        break;

                    case 7:
                        _context3.next = 9;
                        return _fsPromise2.default.exists(outputDirectory);

                    case 9:
                        if (_context3.sent) {
                            _context3.next = 11;
                            break;
                        }

                        errors.push('Directory not found: ' + outputDirectory);

                    case 11:

                        if (!_commander2.default.cookie) {
                            errors.push('Cookie parameter is required.');
                        }

                        if (!_commander2.default.sessionId) {
                            errors.push('Session ID parameter is required.');
                        }

                        privateKey = void 0;

                        if (_commander2.default.privateKeyFile) {
                            _context3.next = 18;
                            break;
                        }

                        errors.push('Private key file parameter is required.');
                        _context3.next = 28;
                        break;

                    case 18:
                        _context3.next = 20;
                        return _fsPromise2.default.exists(_commander2.default.privateKeyFile);

                    case 20:
                        if (_context3.sent) {
                            _context3.next = 24;
                            break;
                        }

                        errors.push('Private key file not found: ' + _commander2.default.privateKeyFile);
                        _context3.next = 28;
                        break;

                    case 24:
                        _context3.next = 26;
                        return getPrivateKey(_commander2.default.privateKeyFile);

                    case 26:
                        if (privateKey = _context3.sent) {
                            _context3.next = 28;
                            break;
                        }

                        errors.push('Invalid private key file: ' + _commander2.default.privateKeyFile);

                    case 28:

                        if (errors.length > 0) {
                            console.error('Errors:\n' + errors.map(function (e) {
                                return ' - ' + e;
                            }).join('\n'));
                            process.exit(1);
                        }

                        _context3.next = 31;
                        return decryptPrivateKey(privateKey);

                    case 31:
                        return _context3.abrupt('return', { cookie: _commander2.default.cookie, sessionId: _commander2.default.sessionId, privateKey: privateKey, outputDirectory: outputDirectory });

                    case 32:
                    case 'end':
                        return _context3.stop();
                }
            }
        }, _callee3, this);
    }));

    return function getParams() {
        return _ref3.apply(this, arguments);
    };
}();

var main = function () {
    var _ref4 = _asyncToGenerator(regeneratorRuntime.mark(function _callee4() {
        var _ref5, cookie, sessionId, privateKey, outputDirectory, logger, conversationFetcher, exporter;

        return regeneratorRuntime.wrap(function _callee4$(_context4) {
            while (1) {
                switch (_context4.prev = _context4.next) {
                    case 0:
                        _context4.next = 2;
                        return getParams();

                    case 2:
                        _ref5 = _context4.sent;
                        cookie = _ref5.cookie;
                        sessionId = _ref5.sessionId;
                        privateKey = _ref5.privateKey;
                        outputDirectory = _ref5.outputDirectory;

                        logger = function logger(msg) {
                            return console.log(msg);
                        };

                        conversationFetcher = new _ConversationFetcher2.default(cookie, sessionId, privateKey, logger);
                        exporter = new _Exporter2.default(conversationFetcher, logger);
                        _context4.next = 12;
                        return exporter.exportEmails(outputDirectory);

                    case 12:
                        return _context4.abrupt('return', _context4.sent);

                    case 13:
                    case 'end':
                        return _context4.stop();
                }
            }
        }, _callee4, this);
    }));

    return function main() {
        return _ref4.apply(this, arguments);
    };
}();

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _fsPromise = require('fs-promise');

var _fsPromise2 = _interopRequireDefault(_fsPromise);

var _openpgp = require('openpgp');

var openpgp = _interopRequireWildcard(_openpgp);

var _commander = require('commander');

var _commander2 = _interopRequireDefault(_commander);

var _passwordPrompt = require('password-prompt');

var _passwordPrompt2 = _interopRequireDefault(_passwordPrompt);

var _ConversationFetcher = require('./ConversationFetcher');

var _ConversationFetcher2 = _interopRequireDefault(_ConversationFetcher);

var _Exporter = require('./Exporter');

var _Exporter2 = _interopRequireDefault(_Exporter);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

main().then(function () {}).catch(function (err) {
    return console.error(err.stack);
});